@@ -17,6 +17,7 @@
 
 #include <QSplitter>
 
+#include <kwidgetsaddons_version.h>
 #include <KIO/OpenFileManagerWindowJob>
 #include <KMessageBox>
 #include <QMenu>
@@ -206,7 +207,7 @@ namespace Konversation
 
             if (index.isValid())
             {
-                Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                 if (transfer)
                 {
                     m_detailPanel->setTransfer(transfer);
@@ -221,7 +222,7 @@ namespace Konversation
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Receive &&
                     index.data(TransferListModel::TransferStatus).toInt() == Transfer::Queued)
                 {
-                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->start();
@@ -237,7 +238,7 @@ namespace Konversation
             for (const QModelIndex &index : selectedRowIndices) {
                 if (index.data(TransferListModel::TransferStatus).toInt() < Transfer::Done)
                 {
-                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->abort();
@@ -255,7 +256,7 @@ namespace Konversation
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Send &&
                     index.data(TransferListModel::TransferStatus).toInt() >= Transfer::Done)
                 {
-                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (!transfer)
                     {
                         continue;
@@ -422,16 +423,25 @@ namespace Konversation
             const int selectedRows = m_transferView->selectedRows().count();
             if (selectedRows > 3)
             {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                int ret = KMessageBox::questionTwoActions(this,
+#else
                 int ret = KMessageBox::questionYesNo(this,
+#endif
                                                      i18np("You have selected %1 file to execute, are you sure you want to continue?",
                                                            "You have selected %1 files to execute, are you sure you want to continue?",
                                                            selectedRows),
-                                                     i18np("Execute %1 file",
-                                                           "Execute %1 files",
-                                                           selectedRows)
+                                                     {},
+                                                     KGuiItem(i18ncp("@action:button", "Execute %1 File", "Execute %1 Files", selectedRows),
+                                                              QStringLiteral("system-run")),
+                                                     KStandardGuiItem::cancel()
                                                      );
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (ret == KMessageBox::SecondaryAction)
+#else
                 if (ret == KMessageBox::No)
+#endif
                 {
                     return;
                 }
@@ -442,7 +452,7 @@ namespace Konversation
                 if (index.data(TransferListModel::TransferType).toInt() == Transfer::Send ||
                     index.data(TransferListModel::TransferStatus).toInt() == Transfer::Done)
                 {
-                    Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                    auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                     if (transfer)
                     {
                         transfer->runFile();
@@ -455,7 +465,7 @@ namespace Konversation
         {
             const auto selectedRowIndices = m_transferView->selectedRows();
             for (const QModelIndex &index : selectedRowIndices) {
-                Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+                auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
                 if (transfer)
                 {
                     openLocation(transfer);
@@ -483,7 +493,7 @@ namespace Konversation
 
         void TransferPanel::doubleClicked(const QModelIndex &index)
         {
-            Transfer *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
+            auto *transfer = qobject_cast<Transfer*>(index.data(TransferListModel::TransferPointer).value<QObject*>());
             if (transfer)
             {
                 transfer->runFile();
